arrc.models.embeddings.tcnn
===========================

.. automodule:: arrc.models.embeddings.tcnn

   
   .. rubric:: Functions

   .. autosummary::
   
      build_tcnn_with_attentionpooling_model
      build_tcnn_with_globalpooling_model
   